@@ -7,4 +7,4 @@ Created on Tue Feb  2 16:20:32 2021
 """
 from . import annotate_identified_variants
 
-__all__ = ['annotate_identified_variants']
+__all__ = ['annotate_identified_variants', 'annotate_mutations']
